#!/usr/bin/env python
# vim: et ai ts=4 sw=4:
import os
import sys

from charmhelpers.core import hookenv
from charmhelpers.core.hookenv import log
from charmhelpers.core import services
from charmhelpers.contrib.cloudfoundry import contexts

import common

hooks = hookenv.Hooks()
fileproperties = {'owner': 'vcap'}

services.register([
    {
        'service': 'cf-cloudcontroller',
        'templates': [
            {'source': 'cf-cloudcontroller.conf'},
            {'source': 'cloud_controller.yml',
             'target': common.CC_CONFIG_FILE,
             'file_properties': fileproperties,
             'contexts': [contexts.NatsContext(),
                          contexts.RouterContext(),
                          contexts.MysqlDSNContext()]}
        ],
    },
    {
        'service': 'cf-cloudcontroller-job',
        'templates': [{'source': 'cf-cloudcontroller-job.conf'}],
    },
])


@hooks.hook('upgrade-charm')
def upgrade_charm():
    pass


@hooks.hook("config-changed")
def config_changed():
    services.reconfigure_services()


@hooks.hook()
def stop():
    services.stop_services()

    
@hooks.hook('db-relation-changed')
def db_relation_changed():
    services.reconfigure_services()
    common.db_migrate()

        
@hooks.hook('nats-relation-changed')
def nats_relation_changed():
    services.reconfigure_services()


@hooks.hook('router-relation-changed')
def router_relation_changed():
    services.reconfigure_services()


if __name__ == '__main__':
    hook_name = os.path.basename(sys.argv[0])
    log("Running {} hook".format(hook_name))
    if hookenv.relation_id():
        log("Relation {} with {}".format(
            hookenv.relation_id(), hookenv.remote_unit()))
    hooks.execute(sys.argv)

